/*
 * arweights.c
 *
 * Code generation for function 'arweights'
 *
 */

/* Include files */
#include "rt_nonfinite.h"
#include "gjbf.h"
#include "arweights.h"
#include "gjbf_data.h"
#include "blas.h"

/* Function Definitions */
void arweights(const real_T rst[16], real_T ar[16])
{
  int32_T k;
  real_T y;
  covrtLogFcn(&emlrtCoverageInstance, 2U, 0);
  covrtLogBasicBlock(&emlrtCoverageInstance, 2U, 0);

  /*   This function computes a set of weights for each sensor in an */
  /*   array based on the distances from sources to the sensors. */
  /*  */
  /*     ar = arweights(rst) */
  /*  */
  /*   input: */
  /*   RST    vector of distances of each sensor to the point in space */
  /*   output: */
  /*   AR     corresponding vector of weights for the array elements */
  /*  */
  /*     Written by Kevin D. Donohue August 2005 */
  /*  */
  /*  Find closest mic to point being considered */
  /*   Create shading values to weight mic inputs as function of */
  /*   distance giving closest mic the most weight. */
  for (k = 0; k < 16; k++) {
    ar[k] = 1.0 / (rst[k] + 2.2204460492503131E-16);
  }

  y = ar[0];
  for (k = 0; k < 15; k++) {
    y += ar[k + 1];
  }

  for (k = 0; k < 16; k++) {
    ar[k] /= y + 2.2204460492503131E-16;
  }
}

/* End of code generation (arweights.c) */
